@@ -40,6 +40,7 @@
 #include "cgiparam.h"
 #include "query.h"
 #include "str.h"
+#include "stringutils.h"
 #include "expand.h"
 
 using namespace std;
@@ -118,8 +119,7 @@ try {
 	} else {
 	    // Seems we're running from the command line so give version
 	    // and allow a query to be entered for testing
-	    cout << PROGRAM_NAME" - "PACKAGE" "VERSION" "
-		"(compiled "__DATE__" "__TIME__")\n";
+	    cout << PROGRAM_NAME " - " PACKAGE " " VERSION "\n";
 	    if (argc > 1) exit(0);
 	    cout << "Enter NAME=VALUE lines, end with blank line\n";
 	    decode_test();
@@ -259,7 +259,7 @@ try {
 	for (MCI i = g.first; i != g.second; i++) {
 	    const string & v = i->second;
 	    // we'll definitely get empty B fields from "-ALL-" options
-	    if (!v.empty() && isalnum(static_cast<unsigned char>(v[0]))) {
+	    if (!v.empty() && C_isalnum(v[0])) {
 		add_bterm(v);
 		filter_v.push_back(v);
 	    }
