@@ -68,6 +68,14 @@
 
 #include <xapian.h>
 
+#ifndef XAPIAN_AT_LEAST
+#define XAPIAN_AT_LEAST(A,B,C) \
+    (XAPIAN_MAJOR_VERSION > (A) || \
+     (XAPIAN_MAJOR_VERSION == (A) && \
+      (XAPIAN_MINOR_VERSION > (B) || \
+       (XAPIAN_MINOR_VERSION == (B) && XAPIAN_REVISION >= (C)))))
+#endif
+
 using namespace std;
 
 using Xapian::Utf8Iterator;
@@ -265,6 +273,14 @@ set_probabilistic(const string &oldp)
 			break;
 		    }
 		    break;
+#if XAPIAN_AT_LEAST(1,2,22)
+		case 'c':
+		    if (s == "flag_cjk_ngram") {
+			f |= Xapian::QueryParser::FLAG_CJK_NGRAM;
+			break;
+		    }
+		    break;
+#endif
 		case 'd':
 		    if (s == "flag_default") {
 			f |= Xapian::QueryParser::FLAG_DEFAULT;
@@ -423,7 +439,7 @@ run_query()
 	    // to be THE query - filtering an empty query will give no
 	    // matches.
 	    std::swap(query, filter);
-	    if (enquire) force_boolean = true;
+	    force_boolean = true;
 	} else {
 	    query = Xapian::Query(Xapian::Query::OP_FILTER, query, filter);
 	}
@@ -670,7 +686,7 @@ html_highlight(const string &s, const string &list,
 		res += bg;
 		res += "\">";
 	    }
-	    word = string(first.raw(), j.raw() - first.raw());
+	    word.assign(first.raw(), j.raw() - first.raw());
 	    res += html_escape(word);
 	    if (!bra.empty()) {
 		res += ket;
@@ -762,7 +778,7 @@ Fields::read_fields(Xapian::docid did) const
 	    if (j != string::npos) {
 		string & value = fields[line.substr(0, j)];
 		if (!value.empty()) value += '\t';
-		value += line.substr(j + 1);
+		value.append(line, j + 1, string::npos);
 	    }
 	} while (++i);
     }
@@ -925,8 +941,7 @@ T(freq,		   1, 1, N, 0), // frequency of a term
 T(ge,		   2, 2, N, 0), // test >=
 T(gt,		   2, 2, N, 0), // test >
 T(highlight,	   2, 4, N, 0), // html escape and highlight words from list
-T(hit,		   0, 0, N, 0), // hit number of current mset entry (starting
-				// from 0
+T(hit,		   0, 0, N, 0), // hit number of current mset entry (0-based)
 T(hitlist,	   1, 1, 0, M), // display hitlist using format in argument
 T(hitsperpage,	   0, 0, N, 0), // hits per page
 T(hostname,	   1, 1, N, 0), // extract hostname from URL
@@ -936,7 +951,7 @@ T(httpheader,      2, 2, N, 0), // arbitrary HTTP header
 T(id,		   0, 0, N, 0), // docid of current doc
 T(if,		   2, 3, 1, 0), // conditional
 T(include,	   1, 1, 1, 0), // include another file
-T(last,		   0, 0, N, M), // m-set number of last hit on page
+T(last,		   0, 0, N, M), // hit number one beyond end of current page
 T(lastpage,	   0, 0, N, M), // number of last hit page
 T(le,		   2, 2, N, 0), // test <=
 T(length,	   1, 1, N, 0), // length of list
@@ -964,7 +979,7 @@ T(percentage,	   0, 0, N, 0), // percentage score of current hit
 T(prettyterm,	   1, 1, N, Q), // pretty print term name
 T(prettyurl,	   1, 1, N, 0), // pretty version of URL
 T(query,	   0, 0, N, Q), // query
-T(querydescription,0, 0, N, Q), // query.get_description()
+T(querydescription,0, 0, N, M), // query.get_description() (run_query() adds filters so M)
 T(queryterms,	   0, 0, N, Q), // list of query terms
 T(range,	   2, 2, N, 0), // return list of values between start and end
 T(record,	   0, 1, N, 0), // record contents of document
@@ -1034,7 +1049,7 @@ eval(const string &fmt, const vector<string> &param)
     string res;
     string::size_type p = 0, q;
     while ((q = fmt.find('$', p)) != string::npos) try {
-	res += fmt.substr(p, q - p);
+	res.append(fmt, p, q - p);
 	string::size_type code_start = q; // note down for error reporting
 	q++;
 	if (q >= fmt.size()) break;
@@ -1155,8 +1170,10 @@ eval(const string &fmt, const vector<string> &param)
 		int id = q0;
 		if (!args.empty()) id = string_to_int(args[0]);
 		Xapian::TermIterator term = db.termlist_begin(id);
-		for ( ; term != db.termlist_end(id); term++)
-		    value = value + *term + '\t';
+		for ( ; term != db.termlist_end(id); term++) {
+		    value += *term;
+		    value += '\t';
+		}
 
 		if (!value.empty()) value.erase(value.size() - 1);
 		break;
@@ -1180,8 +1197,10 @@ eval(const string &fmt, const vector<string> &param)
 	    case CMD_cgilist: {
 		pair<MCI, MCI> g;
 		g = cgi_params.equal_range(args[0]);
-		for (MCI i = g.first; i != g.second; i++)
-		    value = value + i->second + '\t';
+		for (MCI i = g.first; i != g.second; i++) {
+		    value += i->second;
+		    value += '\t';
+		}
 		if (!value.empty()) value.erase(value.size() - 1);
 		break;
 	    }
@@ -1324,7 +1343,8 @@ eval(const string &fmt, const vector<string> &param)
 		while (term != db.allterms_end()) {
 		    string t = *term;
 		    if (!startswith(t, args[0])) break;
-		    value = value + t + '\t';
+		    value += t;
+		    value += '\t';
 		    ++term;
 		}
 
@@ -1379,7 +1399,7 @@ eval(const string &fmt, const vector<string> &param)
 			string::const_iterator i;
 			i = find_if(bra.begin() + 2, bra.end(), p_nottag);
 			ket = "</";
-			ket += bra.substr(1, i - bra.begin() - 1);
+			ket.append(bra, 1, i - bra.begin() - 1);
 			ket += '>';
 		    }
 		}
@@ -1519,11 +1539,11 @@ eval(const string &fmt, const vector<string> &param)
 		    string::size_type split = 0, split2;
 		    while ((split2 = list.find('\t', split)) != string::npos) {
 			if (split) value += inter;
-			value += list.substr(split, split2 - split);
+			value.append(list, split, split2 - split);
 			split = split2 + 1;
 		    }
 		    if (split) value += interlast;
-		    value += list.substr(split);
+		    value.append(list, split, string::npos);
 		    value += post;
 		}
 		break;
@@ -1560,7 +1580,7 @@ eval(const string &fmt, const vector<string> &param)
 		    size_t datalen = cdb_datalen(&cdb);
 		    const void *dat = cdb_get(&cdb, datalen, cdb_datapos(&cdb));
 		    if (q) {
-			value = string(static_cast<const char *>(dat), datalen);
+			value.assign(static_cast<const char *>(dat), datalen);
 		    }
 		}
 
@@ -1877,8 +1897,10 @@ eval(const string &fmt, const vector<string> &param)
 		    while (term != enquire->get_matching_terms_end(q0)) {
 			// check term was in the typed query so we ignore
 			// boolean filter terms
-			if (termset.find(*term) != termset.end())
-			    value = value + *term + '\t';
+			if (termset.find(*term) != termset.end()) {
+			    value += *term;
+			    value += '\t';
+			}
 			++term;
 		    }
 
@@ -2019,7 +2041,7 @@ eval(const string &fmt, const vector<string> &param)
 	error_msg = e.get_msg();
     }
 
-    res += fmt.substr(p);
+    res.append(fmt, p, string::npos);
     return res;
 }
 
@@ -2130,21 +2152,21 @@ parse_omegascript()
 	    suppress_http_headers = true;
 	}
 
-	std::string output = eval_file(fmtname);
+	string output = eval_file(fmtname);
 	if (!set_content_type && !suppress_http_headers) {
-	    cout << "Content-Type: text/html" << std::endl;
+	    cout << "Content-Type: text/html" << endl;
 	    set_content_type = true;
 	}
-	cout << std::endl;
+	if (!suppress_http_headers) cout << endl;
 	cout << output;
     } catch (...) {
 	// Ensure the headers have been output so that any exception gets
 	// reported rather than giving a server error.
 	if (!set_content_type && !suppress_http_headers) {
-	    cout << "Content-Type: text/html" << std::endl;
+	    cout << "Content-Type: text/html" << endl;
 	    set_content_type = true;
 	}
-	cout << std::endl;
+	if (!suppress_http_headers) cout << endl;
 	throw;
     }
 }
@@ -2189,13 +2211,11 @@ ensure_query_parsed()
 	    val = cgi_params.find("xDB");
 	    if (val != cgi_params.end() && val->second != dbname) break;
 	    if (result == SAME_QUERY && force_first_page) {
-		force_first_page = false;
 		val = cgi_params.find("xFILTERS");
-		string xfilters;
-		if (val != cgi_params.end()) xfilters = val->second;
-		if (filters != xfilters) {
-		    // Filters changed since last query
-		    force_first_page = true;
+		if (val != cgi_params.end() && val->second != filters) {
+		    // Filters have changed since last query.
+		} else {
+		    force_first_page = false;
 		}
 	    }
 	    discard_rset = false;
